==> qt-creator-opensource-src-4.0.1.tar.gz: qt-creator-opensource-src-4.0.1/src/libs/sqlite/createtablecommand.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef INTERNAL_CREATETABLECOMMAND_H
#define INTERNAL_CREATETABLECOMMAND_H

#include "columndefinition.h"
#include "utf8string.h"

#include <QMetaType>
#include <QVector>

namespace Internal {

class CreateTableCommand
{
public:
    QVector<ColumnDefinition> definitions;
    Utf8String tableName;
    bool useWithoutRowId;

    static void registerType();

};

} // namespace Internal

Q_DECLARE_METATYPE(Internal::CreateTableCommand)

#endif // INTERNAL_CREATETABLECOMMAND_H

==> qt-creator-opensource-src-4.1.0.tar.gz: qt-creator-opensource-src-4.1.0/src/libs/sqlite/createtablecommand.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "columndefinition.h"
#include "utf8string.h"

#include <QMetaType>
#include <QVector>

namespace Internal {

class CreateTableCommand
{
public:
    QVector<ColumnDefinition> definitions;
    Utf8String tableName;
    bool useWithoutRowId;

    static void registerType();

};

} // namespace Internal

Q_DECLARE_METATYPE(Internal::CreateTableCommand)
